@@ -1,9 +1,9 @@
 # codegen: frontend, sdk
-from typing import Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 from pydantic import BaseModel, Field
 
-from maitai_models.config import Config
+from maitai.models.config import Config
 
 
 class ApplicationObjective(BaseModel):
@@ -20,9 +20,10 @@ class ApplicationAction(BaseModel):
     application_id: int
     meta: Optional[Config] = None
     last_activity: Optional[int] = 0
-    notifications_enabled: bool
+    notifications_enabled: bool = False
     prompt: Optional[str] = None
     request_count: Optional[int] = 0
+    intent_group_id: Optional[int] = -1
 
 
 class Application(BaseModel):
@@ -44,8 +45,8 @@ class ApplicationContext(BaseModel):
     id: Optional[int] = -1
     date_created: Optional[Union[int, float]] = 0
     application_id: Optional[int] = None
-    context_body: Optional[str] = None
+    context_body: Optional[Union[str, Dict[Any, Any]]] = None
     context_path: Optional[str] = None
-    context_type: Optional[str] = None
+    context_type: Optional[str] = "TEXT"
     reference: Optional[str] = None
     description: Optional[str] = None
